@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2001,2002,2009 Bernhard R. Link <brlink@debian.org>
+    Copyright (C) 2001,2002,2009,2012 Bernhard R. Link <brlink@debian.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as
@@ -167,6 +167,9 @@ static inline enum nss_status g_search(FILE *stream, const char *name, const gid
 		/* extract name */
 		while (isspace(*p))
 			++p;
+		/* Ignore empty lines */
+		if (*p == '\0')
+			continue;
 		t_name = p;
 		TOCOLON(p, h);
 		if (name && strcmp(name, t_name) != 0)
