@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2001,2002,2009 Bernhard R. Link <brlink@debian.org>
+    Copyright (C) 2001,2002,2009,2012 Bernhard R. Link <brlink@debian.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as
@@ -153,12 +153,15 @@ static enum nss_status shadow_search(FILE *stream, const char *name, struct spwd
 			h--;
 		}
 		/* Ignore comments */
-		if( *p == '#' )
+		if( *p == '#')
 			continue;
 
 		/* extract name */
 		while (isspace(*p))
 			++p;
+		/* Ignore empty lines */
+		if (*p == '\0')
+			continue;
 		t_namp = p;
 		TOCOLON(p, h);
 		if( name && strcmp(name, t_namp) != 0 )
